@@ -1,5 +1,4 @@
 # -*- coding: utf-8 -*-
-
 # Copyright 2020 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -14,12 +13,10 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-
 import proto  # type: ignore
 
-
 from google.cloud.scheduler_v1.types import job as gcs_job
-from google.protobuf import field_mask_pb2 as field_mask  # type: ignore
+from google.protobuf import field_mask_pb2  # type: ignore
 
 
 __protobuf__ = proto.module(
@@ -68,11 +65,9 @@ class ListJobsRequest(proto.Message):
             while iterating through pages.
     """
 
-    parent = proto.Field(proto.STRING, number=1)
-
-    page_size = proto.Field(proto.INT32, number=5)
-
-    page_token = proto.Field(proto.STRING, number=6)
+    parent = proto.Field(proto.STRING, number=1,)
+    page_size = proto.Field(proto.INT32, number=5,)
+    page_token = proto.Field(proto.STRING, number=6,)
 
 
 class ListJobsResponse(proto.Message):
@@ -100,8 +95,7 @@ class ListJobsResponse(proto.Message):
         return self
 
     jobs = proto.RepeatedField(proto.MESSAGE, number=1, message=gcs_job.Job,)
-
-    next_page_token = proto.Field(proto.STRING, number=2)
+    next_page_token = proto.Field(proto.STRING, number=2,)
 
 
 class GetJobRequest(proto.Message):
@@ -114,7 +108,7 @@ class GetJobRequest(proto.Message):
             ``projects/PROJECT_ID/locations/LOCATION_ID/jobs/JOB_ID``.
     """
 
-    name = proto.Field(proto.STRING, number=1)
+    name = proto.Field(proto.STRING, number=1,)
 
 
 class CreateJobRequest(proto.Message):
@@ -136,8 +130,7 @@ class CreateJobRequest(proto.Message):
             response.
     """
 
-    parent = proto.Field(proto.STRING, number=1)
-
+    parent = proto.Field(proto.STRING, number=1,)
     job = proto.Field(proto.MESSAGE, number=2, message=gcs_job.Job,)
 
 
@@ -159,8 +152,9 @@ class UpdateJobRequest(proto.Message):
     """
 
     job = proto.Field(proto.MESSAGE, number=1, message=gcs_job.Job,)
-
-    update_mask = proto.Field(proto.MESSAGE, number=2, message=field_mask.FieldMask,)
+    update_mask = proto.Field(
+        proto.MESSAGE, number=2, message=field_mask_pb2.FieldMask,
+    )
 
 
 class DeleteJobRequest(proto.Message):
@@ -173,7 +167,7 @@ class DeleteJobRequest(proto.Message):
             ``projects/PROJECT_ID/locations/LOCATION_ID/jobs/JOB_ID``.
     """
 
-    name = proto.Field(proto.STRING, number=1)
+    name = proto.Field(proto.STRING, number=1,)
 
 
 class PauseJobRequest(proto.Message):
@@ -186,7 +180,7 @@ class PauseJobRequest(proto.Message):
             ``projects/PROJECT_ID/locations/LOCATION_ID/jobs/JOB_ID``.
     """
 
-    name = proto.Field(proto.STRING, number=1)
+    name = proto.Field(proto.STRING, number=1,)
 
 
 class ResumeJobRequest(proto.Message):
@@ -199,7 +193,7 @@ class ResumeJobRequest(proto.Message):
             ``projects/PROJECT_ID/locations/LOCATION_ID/jobs/JOB_ID``.
     """
 
-    name = proto.Field(proto.STRING, number=1)
+    name = proto.Field(proto.STRING, number=1,)
 
 
 class RunJobRequest(proto.Message):
@@ -212,7 +206,7 @@ class RunJobRequest(proto.Message):
             ``projects/PROJECT_ID/locations/LOCATION_ID/jobs/JOB_ID``.
     """
 
-    name = proto.Field(proto.STRING, number=1)
+    name = proto.Field(proto.STRING, number=1,)
 
 
 __all__ = tuple(sorted(__protobuf__.manifest))
